import {lazy, FC, Suspense} from 'react'
import {Route, Routes, Navigate} from 'react-router-dom'
import {MasterLayout} from '../../_metronic/layout/MasterLayout'
import TopBarProgress from 'react-topbar-progress-indicator'
import {DashboardWrapper} from '../pages/dashboard/DashboardWrapper'
import {MenuTestPage} from '../pages/MenuTestPage'
import {getCSSVariableValue} from '../../_metronic/assets/ts/_utils'
import {WithChildren} from '../../_metronic/helpers'
import BuilderPageWrapper from '../pages/layout-builder/BuilderPageWrapper'
import PositionsPage from '../modules/apps/management/PositionsPage'
import GptGeneratorsPage from '../modules/gptgenerators/GptGeneratorsPage'

const PrivateRoutes = () => {
  const UserLandingPage = lazy(() => import('../modules/apps/management/object-list/landingpage/person/PersonLandingPage'))
  const OrganisationLandingPage = lazy(() => import('../modules/apps/management/object-list/landingpage/organisation/OrganisationLandingPage'))
  const PositionLandingPage = lazy(() => import('../modules/apps/management/object-list/landingpage/position/PositionLandingPage'))
  const WizardsPage = lazy(() => import('../modules/wizards/WizardsPage'))
  const WidgetsPage = lazy(() => import('../modules/widgets/WidgetsPage'))
  const ChatPage = lazy(() => import('../modules/apps/chat/ChatPage'))
  const UsersPage = lazy(() => import('../modules/apps/management/UsersPage'))
  const OrganisationsPage = lazy(() => import('../modules/apps/management/OrganisationsPage'))


  return (
    <Routes>
      <Route element={<MasterLayout />}>
        {/* Redirect to Dashboard after success login/registartion */}
        <Route path='auth/*' element={<Navigate to='/dashboard' />} />
        {/* Pages */}
        <Route path='dashboard' element={<DashboardWrapper />} />
        <Route path='builder' element={<BuilderPageWrapper />} />
        <Route path='menu-test' element={<MenuTestPage />} />
        {/* Lazy Modules */}
        <Route
          path='person/*'
          element={
            <SuspensedView>
              <UserLandingPage />
            </SuspensedView>
          }
        />
          <Route
          path='organisation/*'
          element={
            <SuspensedView>
              <OrganisationLandingPage />
            </SuspensedView>
          }
        />

      <Route
          path='position/*'
          element={
            <SuspensedView>
              <PositionLandingPage />
            </SuspensedView>
          }
        />
        <Route
          path='klokgpt/generate/*'
          element={
            <SuspensedView>
              <GptGeneratorsPage />
            </SuspensedView>
          }
        />
        <Route
          path='crafted/pages/wizards/*'
          element={
            <SuspensedView>
              <WizardsPage />
            </SuspensedView>
          }
        />
        <Route
          path='crafted/widgets/*'
          element={
            <SuspensedView>
              <WidgetsPage />
            </SuspensedView>
          }
        />
        <Route
          path='apps/chat/*'
          element={
            <SuspensedView>
              <ChatPage />
            </SuspensedView>
          }
        />
        <Route
          path='apps/management/persons/*'
          element={
            <SuspensedView>
              <UsersPage />
            </SuspensedView>
          }
        />
        <Route
        path='apps/management/organisations/*'
        element={
          <SuspensedView>
            <OrganisationsPage />
          </SuspensedView>
        }
      />
       <Route
        path='apps/management/positions/*'
        element={
          <SuspensedView>
            <PositionsPage />
          </SuspensedView>
        }
      />
        {/* Page Not Found */}
        <Route path='*' element={<Navigate to='/error/404' />} />
      </Route>
    </Routes>
  )
}

const SuspensedView: FC<WithChildren> = ({children}) => {
  const baseColor = getCSSVariableValue('--kt-primary')
  TopBarProgress.config({
    barColors: {
      '0': baseColor,
    },
    barThickness: 1,
    shadowBlur: 5,
  })
  return <Suspense fallback={<TopBarProgress />}>{children}</Suspense>
}

export {PrivateRoutes}
